@@ -8,6 +8,12 @@ function WatchedExprManager(rest_api) {
         return (expr in watchedExpressionToDivId);
     }
 
+    this.expressions = function() {
+        console.log('getting expressions');
+        console.log(watchedExpressionToDivId);
+        return Object.keys(watchedExpressionToDivId);
+    }
+
     function exprForElt($elt) {
         var divId = $elt.closest('.watched-expression').attr('id');
         for (var expr in watchedExpressionToDivId) {
